@@ -40,14 +40,21 @@ get_all_channel_video_stats <- function(channel_id = NULL, mine = FALSE, ...) {
   details <- lapply(vid_ids, get_video_details)
   res_df <- do.call(what = bind_rows, lapply(res, data.frame))
 
-  details_tot <- data.frame(id = NA, title = NA, publication_date = NA)
+  details_tot <- data.frame(id = NA, title = NA,
+                            publication_date = NA, description = NA,
+                            channel_id = NA, channel_title = NA)
 
   for (p in 1:length(details)) {
     id <- details[[p]]$items[[1]]$id
     title <- details[[p]]$items[[1]]$snippet$title
     publication_date <- details[[p]]$items[[1]]$snippet$publishedAt
+    description <- details[[p]]$items[[1]]$snippet$description
+    channel_id <- details[[p]]$items[[1]]$snippet$channelId
+    channel_title <- details[[p]]$items[[1]]$snippet$channelTitle
 
-    detail <- data.frame(id = id, title = title, publication_date = publication_date)
+    detail <- data.frame(id = id, title = title,
+                         publication_date = publication_date, description = description,
+                         channel_id = channel_id, channel_title = channel_title)
     details_tot <- rbind(detail, details_tot)
   }
 
