@@ -1,31 +1,31 @@
 #' Get Playlist Items
-#' 
+#'
 #' @param filter string; Required.
 #' named vector of length 1
-#' potential names of the entry in the vector: 
+#' potential names of the entry in the vector:
 #' \code{item_id}: comma-separated list of one or more unique playlist item IDs.
 #' \code{playlist_id}: YouTube playlist ID.
-#' 
+#'
 #' @param part Required. Comma separated string including one or more of the following: \code{contentDetails, id, snippet, status}. Default: \code{contentDetails}.
-#' @param max_results Maximum number of items that should be returned. Integer. Optional. Default is 50. 
+#' @param max_results Maximum number of items that should be returned. Integer. Optional. Default is 50.
 #' If over 50, all the results are returned.
-#' @param simplify returns a data.frame rather than a list. 
+#' @param simplify returns a data.frame rather than a list.
 #' @param page_token specific page in the result set that should be returned, optional
 #' @param video_id  Optional. request should return only the playlist items that contain the specified video.
 #' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
-#' 
+#'
 #' @return playlist items
 #' @export
 #' @references \url{https://developers.google.com/youtube/v3/docs/playlists/list}
-#' 
+#'
 #' @examples
 #' \dontrun{
-#' 
+#'
 #' # Set API token via yt_oauth() first
-#' 
-#' get_playlist_items(filter = 
+#'
+#' get_playlist_items(filter =
 #'                        c(playlist_id = "PLrEnWoR732-CN09YykVof2lxdI3MLOZda"))
-#' get_playlist_items(filter = 
+#' get_playlist_items(filter =
 #'                        c(playlist_id = "PL0fOlXVeVW9QMO3GoESky4yDgQfK2SsXN"),
 #'                        max_results = 51)
 #' }
@@ -76,14 +76,12 @@ get_playlist_items <- function (filter = NULL, part = "contentDetails",
   }
 
   if (simplify == TRUE) {
-    if (length(res) > 5) {
-      res <- append(res, list(NA), length(res) - 1)
-      res <- plyr::ldply(lapply(unlist(res[seq(5, length(res), 6)],
-                                                                 recursive = F),
-                                                                 as.data.frame))
-    } else {
-       res <- plyr::ldply(lapply(unlist(res[length(res)], recursive = F), as.data.frame))
-    }
+    res <- do.call(rbind,lapply(
+      unlist(
+        res[which(names(res) == "items")],
+        recursive = FALSE),
+      as.data.frame, stringsAsFactors = FALSE)
+    )
   }
   res
 }
