@@ -1,4 +1,7 @@
-#' \pkg{tuber} provides access to the YouTube API V3.
+#' @title \pkg{tuber} provides access to the YouTube API V3.
+#'
+#' @description \pkg{tuber} provides access to the YouTube API V3 via
+#' RESTful calls.
 #'
 #' @name tuber
 #' @importFrom httr GET POST DELETE authenticate config stop_for_status upload_file content oauth_endpoints oauth_app oauth2.0_token
@@ -10,20 +13,32 @@
 NULL
 
 #' Check if authentication token is in options
-#'
+#' @return A Token2.0 class
+#' @export
+yt_token <- function() {
+  getOption("google_token")
+}
 
+#' @export
+#' @rdname yt_token
+yt_authorized <- function() {
+  !is.null(yt_token())
+}
+
+#' @rdname yt_token
 yt_check_token <- function() {
 
-  app_token <- getOption("google_token")
-    if (is.null(app_token)) stop("Please get a token using yt_oauth().\n")
+  if (!yt_authorized()) {
+    stop("Please get a token using yt_oauth().\n")
+  }
 
 }
 
 #'
 #' GET
-#' 
-#' @param path path to specific API request URL 
-#' @param query query list 
+#'
+#' @param path path to specific API request URL
+#' @param query query list
 #' @param \dots Additional arguments passed to \code{\link[httr]{GET}}.
 #' @return list
 
@@ -42,12 +57,12 @@ tuber_GET <- function(path, query, ...) {
 
 #'
 #' POST
-#' 
-#' @param path path to specific API request URL 
+#'
+#' @param path path to specific API request URL
 #' @param query query list
-#' @param body passing image through body 
+#' @param body passing image through body
 #' @param \dots Additional arguments passed to \code{\link[httr]{GET}}.
-#' 
+#'
 #' @return list
 
 tuber_POST <- function(path, query, body = "", ...) {
@@ -66,9 +81,9 @@ tuber_POST <- function(path, query, body = "", ...) {
 
 #'
 #' DELETE
-#' 
-#' @param path path to specific API request URL 
-#' @param query query list 
+#'
+#' @param path path to specific API request URL
+#' @param query query list
 #' @param \dots Additional arguments passed to \code{\link[httr]{GET}}.
 #' @return list
 
@@ -87,7 +102,7 @@ tuber_DELETE <- function(path, query, ...) {
 
 #'
 #' Request Response Verification
-#' 
+#'
 #' @param  req request
 #' @return in case of failure, a message
 
