@@ -102,11 +102,8 @@ yt_search <- function (term = NULL, max_results = 50, channel_id = NULL,
     video_caption <- video_license <- video_definition <-
     video_type <- video_syndicated <- NULL
   }
-
-  # For queries with spaces
-  format_term <- paste0(unlist(strsplit(term, " ")), collapse = "%20")
-
-  querylist <- list(part = "snippet", q = format_term, maxResults = max_results,
+  
+  querylist <- list(part = "snippet", q = term, maxResults = max_results,
                     channelId = channel_id, type = type,
                     channelType = channel_type, eventType = event_type,
                     location = location,
@@ -179,7 +176,16 @@ yt_search <- function (term = NULL, max_results = 50, channel_id = NULL,
   if (identical(simplify, TRUE)) {
 
     if (res$pageInfo$totalResults != 0) {
-      simple_res  <- lapply(res$items, function(x) unlist(x$snippet))
+      if (type == "video") {
+
+      simple_res  <- lapply(res$items,
+                                   function(x) {
+                                   c(video_id = x$id$videoId, unlist(x$snippet))
+                              })
+      } else {
+
+       simple_res  <- lapply(res$items, function(x) unlist(x$snippet))
+      }
       resdf       <- ldply(simple_res, rbind)
       return(resdf)
     } else {
